==> okteta_0.25.5.orig.tar.xz: okteta-0.25.5/kasten/controllers/view/structures/script/classes/bitfieldscriptclass.h <==
/*
 *   This file is part of the Okteta Kasten Framework, made within the KDE community.
 *
 *   Copyright 2012 Alex Richardson <alex.richardson@gmx.de>
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) version 3, or any
 *   later version accepted by the membership of KDE e.V. (or its
 *   successor approved by the membership of KDE e.V.), which shall
 *   act as a proxy defined in Section 6 of version 3 of the license.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef BITFIELDSCRIPTCLASS_H
#define BITFIELDSCRIPTCLASS_H

#include "primitivescriptclass.h"

class BitfieldScriptClass : public PrimitiveScriptClass
{
    Q_DISABLE_COPY(BitfieldScriptClass)

public:
    BitfieldScriptClass(QScriptEngine* engine, ScriptHandlerInfo* handlerInfo);
    ~BitfieldScriptClass() override;

protected:
    bool queryAdditionalProperty(const DataInformation* data, const QScriptString& name, QScriptClass::QueryFlags* flags, uint* id) override;
    QScriptValue additionalProperty(const DataInformation* data, const QScriptString& name, uint id) override;
    bool setAdditionalProperty(DataInformation* data, const QScriptString& name, uint id, const QScriptValue& value) override;

protected:
    QScriptString s_width;
};

#endif // BITFIELDSCRIPTCLASS_H

==> okteta_17.12.3.orig.tar.xz: okteta-17.12.3/kasten/controllers/view/structures/script/classes/bitfieldscriptclass.h <==
/*
 *   This file is part of the Okteta Kasten Framework, made within the KDE community.
 *
 *   Copyright 2012 Alex Richardson <alex.richardson@gmx.de>
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) version 3, or any
 *   later version accepted by the membership of KDE e.V. (or its
 *   successor approved by the membership of KDE e.V.), which shall
 *   act as a proxy defined in Section 6 of version 3 of the license.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef BITFIELDSCRIPTCLASS_H
#define BITFIELDSCRIPTCLASS_H

#include "primitivescriptclass.h"

class BitfieldScriptClass : public PrimitiveScriptClass {
    Q_DISABLE_COPY(BitfieldScriptClass)
public:
    BitfieldScriptClass(QScriptEngine* engine, ScriptHandlerInfo* handlerInfo);
    ~BitfieldScriptClass() override;
protected:
    bool queryAdditionalProperty(const DataInformation* data, const QScriptString& name, QScriptClass::QueryFlags* flags, uint* id) override;
    QScriptValue additionalProperty(const DataInformation* data, const QScriptString& name, uint id) override;
    bool setAdditionalProperty(DataInformation* data, const QScriptString& name, uint id, const QScriptValue& value) override;
protected:
    QScriptString s_width;
};

#endif // BITFIELDSCRIPTCLASS_H
